/*
 * Copyright (c) 2011, Patrik Dufresne. All rights reserved.
 * Patrik Dufresne PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.planimod.core.comparators;

import java.util.Comparator;

import org.apache.commons.collections.ComparatorUtils;
import org.apache.commons.collections.Transformer;
import org.apache.commons.collections.comparators.ComparatorChain;

import com.planimod.core.Position;

/**
 * Utility class to sort position.
 * 
 * @author Patrik Dufresne
 * 
 */
public class PositionComparators {
	/**
	 * Comparator to position bye name.
	 * 
	 * @return
	 */
	public static Comparator<Position> byName() {
		return ComparatorUtils.nullLowComparator(ComparatorUtils
				.transformedComparator(
						ComparatorUtils.nullLowComparator(ComparatorUtils
								.naturalComparator()), new Transformer() {
							@Override
							public Object transform(Object arg0) {
								return ((Position) arg0).getName();
							}
						}));
	}

	public static Comparator<Position> bySectionClassifiedAndName() {

		ComparatorChain chain = new ComparatorChain();

		// Compare section's name
		chain.addComparator(ComparatorUtils.nullLowComparator(ComparatorUtils
				.transformedComparator(SectionComparators.byName(),
						new Transformer() {
							@Override
							public Object transform(Object arg0) {
								return ((Position) arg0).getSection();
							}
						})));

		// Classified & name
		chain.addComparator(byClassifiedName());

		return chain;
	}

	/**
	 * Comparator to sort Position by classified position (first) and then by
	 * name.
	 * 
	 * @return
	 */
	public static Comparator<Position> byClassifiedName() {
		ComparatorChain chain = new ComparatorChain();

		// Classified
		chain.addComparator(ComparatorUtils.nullLowComparator(ComparatorUtils
				.transformedComparator(ComparatorUtils.booleanComparator(true),
						new Transformer() {
							@Override
							public Object transform(Object arg0) {
								return Boolean.valueOf(((Position) arg0)
										.getClassified());
							}
						})));

		// Name
		chain.addComparator(byName());

		return chain;
	}
}
