/*
 * Copyright (c) 2011, Patrik Dufresne. All rights reserved.
 * Patrik Dufresne PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.planimod.ui.views.planif;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.databinding.observable.IObservable;
import org.eclipse.core.databinding.observable.Realm;
import org.eclipse.core.databinding.observable.value.IObservableValue;

import com.patrikdufresne.managers.ManagerException;
import com.patrikdufresne.managers.databinding.ManagedObjectComputedSet;
import com.planimod.core.Employee;
import com.planimod.core.GeneratePlanifContext;
import com.planimod.core.ProposedTasks.ProposedWarning;
import com.planimod.core.Task;

public class ProposedWarningComputedSet extends ManagedObjectComputedSet {
	/**
	 * The managers.
	 */
	private GeneratePlanifContext context;
	/**
	 * Observable employee.
	 */
	private IObservableValue employee;
	/**
	 * Property listener
	 */
	private PropertyChangeListener listener = new PropertyChangeListener() {
		@Override
		public void propertyChange(PropertyChangeEvent evt) {
			getRealm().exec(new Runnable() {
				@Override
				public void run() {
					makeDirty();
				}
			});
		}
	};

	@Override
	protected void makeDirty() {
		super.makeDirty();
	}

	/**
	 * Create a new observable set of employee.
	 * 
	 * @param context
	 *            the generate planif context
	 */
	public ProposedWarningComputedSet(GeneratePlanifContext context,
			IObservableValue employee) {
		this(Realm.getDefault(), context, employee);
	}

	/**
	 * Create a new observable set of employee.
	 * 
	 * @param realm
	 *            the realm
	 * @param site
	 *            The view site to get the generate planif context
	 * @param lockedElements
	 *            the observable locked elements
	 */
	public ProposedWarningComputedSet(Realm realm,
			GeneratePlanifContext context, IObservableValue employee) {
		super(context.getManagers(), Task.class, null,
				new IObservable[] { employee });
		this.context = context;
		this.employee = employee;
	}

	@Override
	public synchronized void dispose() {
		super.dispose();
		this.context = null;
	}

	/**
	 * This implementation query the database to get the employees qualify for
	 * all null planif event.
	 */
	@Override
	protected Collection doList() throws ManagerException {
		if (getEmployee() == null) {
			return Collections.EMPTY_SET;
		}
		// Remove duplicated code.
		Map<Integer, ProposedWarning> warnings = new HashMap<Integer, ProposedWarning>();
		for (ProposedWarning w : this.context.getProposedTasks().warnings(
				getEmployee())) {
			warnings.put(Integer.valueOf(w.getCode()), w);
		}
		return warnings.values();
	}

	/**
	 * Return the current employee value or null if the observable doesn't
	 * contain an employee object.
	 * 
	 * @return the current employee or null.
	 */
	protected Employee getEmployee() {
		if (this.employee.getValue() instanceof Employee) {
			return (Employee) this.employee.getValue();
		}
		return null;
	}

	@Override
	protected void startListening() {
		super.startListening();
		this.context.addPropertyChangeListener(
				GeneratePlanifContext.LIST_TASK_BY_EMPLOYEE, this.listener);
	}

	@Override
	protected void stopListening() {
		super.stopListening();
		this.context.removePropertyChangeListener(
				GeneratePlanifContext.LIST_TASK_BY_EMPLOYEE, this.listener);
	}

}